@@ -75,12 +75,6 @@ public interface ConfigMBean {
      */
     void resetDebugInfo();
 
-    /**
-     * Return information about the found MBeanServers
-     * @return info about MBeanServers
-     */
-    String mBeanServerInfo();
-
     // Attributes
 
     /**
@@ -93,7 +87,7 @@ public interface ConfigMBean {
 
     /**
      * Number of global limit for history entries. No attribute historization can exceed this
-     * limit (i.e if in {@link #setHistoryEntriesForAttribute(String, String, String, String, int)} 
+     * limit (i.e if in {@link #setHistoryEntriesForAttribute(String, String, String, String, int)}
      * the <code>pMaxEntries</code> is set larger than this limit, the global limit will be taken}
      *
      * @return the global history limit
